# gbrokerexe

<div align="right">

[![Build status](https://github.com/altcp/gbrokerexe/workflows/build/badge.svg?branch=master&event=push)](https://github.com/altcp/gbrokerexe/actions?query=workflow%3Abuild)
[![Dependencies Status](https://img.shields.io/badge/dependencies-up%20to%20date-brightgreen.svg)](https://github.com/altcp/gbrokerexe/pulls?utf8=%E2%9C%93&q=is%3Apr%20author%3Aapp%2Fdependabot)
[![pypi](https://img.shields.io/pypi/v/gbrokerexe.svg)](https://pypi.python.org/pypi/gbrokerexe)

</div>

Generic Python Package for Brokerage and Trade Executions.
<p>&nbsp;</p>



## Features 

<div align="right">

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) 
[![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/altcp/gbrokerexe/blob/master/.pre-commit-config.yaml)

</div>

* oanda API 
* alpaca-trade API
* others
<p>&nbsp;</p>



## Releases

<div align="right">

[![Release Drafter](https://github.com/altcp/gbrokerexe/actions/workflows/release-drafter.yml/badge.svg)](https://github.com/altcp/gbrokerexe/actions/workflows/release-drafter.yml)
[![Semantic Versions](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--versions-e10079.svg)](https://github.com/altcp/gdemandfcast/releases)

</div>

You can see the list of available releases on the [GitHub Releases](https://github.com/altcp/gdemandfcast/releases) page. &nbsp;
We use [`Release Drafter`](https://github.com/marketplace/actions/release-drafter). As pull requests are merged, a draft release is kept up-to-date listing the changes.
<p>&nbsp;</p>



## License

<div align="right">

[![License](https://img.shields.io/github/license/altcp/gbrokerexe)](https://github.com/altcp/gbrokerexe/blob/master/LICENSE)

</div>

This project is licensed under the terms of the `GNU GPL v3.0` license.
<p>&nbsp;</p>



## 📃 Citation
<p>&nbsp;</p>

```bibtex
@misc{gbrokerexe,
  author = {altcp},
  title = {Generic Python Package for Brokerage and Trade Executions},
  year = {2021},
  publisher = {GitHub},
  journal = {GitHub repository},
  howpublished = {https://github.com/altcp/gbrokerexe}
}
```
<p>&nbsp;</p>


## Credits 
<div align="right">

[![🚀 Your next Python package needs a bleeding-edge project structure.](https://img.shields.io/badge/python--package--template-%F0%9F%9A%80-brightgreen)](https://github.com/TezRomacH/python-package-template)

</div>

This project was generated with [`python-package-template`](https://github.com/TezRomacH/python-package-template)
